==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkStructuredAMRGridConnectivity.java <==
// java wrapper for vtkStructuredAMRGridConnectivity object
//

package vtk;
import vtk.*;

public class vtkStructuredAMRGridConnectivity extends vtkAbstractGridConnectivity
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2(int id0,int id1,int id2);
  public void Initialize(int id0,int id1,int id2)
    { Initialize_2(id0,id1,id2); }

  private native void ComputeNeighbors_3();
  public void ComputeNeighbors()
    { ComputeNeighbors_3(); }

  private native void CreateGhostLayers_4(int id0);
  public void CreateGhostLayers(int id0)
    { CreateGhostLayers_4(id0); }

  private native void RegisterGrid_5(int id0,int id1,int id2,int id3[],vtkUnsignedCharArray id4,vtkUnsignedCharArray id5,vtkPointData id6,vtkCellData id7,vtkPoints id8);
  public void RegisterGrid(int id0,int id1,int id2,int id3[],vtkUnsignedCharArray id4,vtkUnsignedCharArray id5,vtkPointData id6,vtkCellData id7,vtkPoints id8)
    { RegisterGrid_5(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void RegisterGrid_6(int id0,int id1,int id2[],vtkUnsignedCharArray id3,vtkUnsignedCharArray id4,vtkPointData id5,vtkCellData id6,vtkPoints id7);
  public void RegisterGrid(int id0,int id1,int id2[],vtkUnsignedCharArray id3,vtkUnsignedCharArray id4,vtkPointData id5,vtkCellData id6,vtkPoints id7)
    { RegisterGrid_6(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void SetBalancedRefinement_7(boolean id0);
  public void SetBalancedRefinement(boolean id0)
    { SetBalancedRefinement_7(id0); }

  private native boolean GetBalancedRefinement_8();
  public boolean GetBalancedRefinement()
    { return GetBalancedRefinement_8(); }

  private native void SetNodeCentered_9(boolean id0);
  public void SetNodeCentered(boolean id0)
    { SetNodeCentered_9(id0); }

  private native boolean GetNodeCentered_10();
  public boolean GetNodeCentered()
    { return GetNodeCentered_10(); }

  private native void SetCellCentered_11(boolean id0);
  public void SetCellCentered(boolean id0)
    { SetCellCentered_11(id0); }

  private native boolean GetCellCentered_12();
  public boolean GetCellCentered()
    { return GetCellCentered_12(); }

  private native int GetNumberOfNeighbors_13(int id0);
  public int GetNumberOfNeighbors(int id0)
    { return GetNumberOfNeighbors_13(id0); }

  private native void GetGhostedExtent_14(int id0,int id1[]);
  public void GetGhostedExtent(int id0,int id1[])
    { GetGhostedExtent_14(id0,id1); }

  public vtkStructuredAMRGridConnectivity() { super(); }

  public vtkStructuredAMRGridConnectivity(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv6h.pkg.tar.xz: vtk/vtkStructuredAMRGridConnectivity.java <==
// java wrapper for vtkStructuredAMRGridConnectivity object
//

package vtk;
import vtk.*;

public class vtkStructuredAMRGridConnectivity extends vtkAbstractGridConnectivity
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2(int id0,int id1,int id2);
  public void Initialize(int id0,int id1,int id2)
    { Initialize_2(id0,id1,id2); }

  private native void ComputeNeighbors_3();
  public void ComputeNeighbors()
    { ComputeNeighbors_3(); }

  private native void CreateGhostLayers_4(int id0);
  public void CreateGhostLayers(int id0)
    { CreateGhostLayers_4(id0); }

  private native void RegisterGrid_5(int id0,int id1,int id2,int id3[],vtkUnsignedCharArray id4,vtkUnsignedCharArray id5,vtkPointData id6,vtkCellData id7,vtkPoints id8);
  public void RegisterGrid(int id0,int id1,int id2,int id3[],vtkUnsignedCharArray id4,vtkUnsignedCharArray id5,vtkPointData id6,vtkCellData id7,vtkPoints id8)
    { RegisterGrid_5(id0,id1,id2,id3,id4,id5,id6,id7,id8); }

  private native void RegisterGrid_6(int id0,int id1,int id2[],vtkUnsignedCharArray id3,vtkUnsignedCharArray id4,vtkPointData id5,vtkCellData id6,vtkPoints id7);
  public void RegisterGrid(int id0,int id1,int id2[],vtkUnsignedCharArray id3,vtkUnsignedCharArray id4,vtkPointData id5,vtkCellData id6,vtkPoints id7)
    { RegisterGrid_6(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void SetBalancedRefinement_7(boolean id0);
  public void SetBalancedRefinement(boolean id0)
    { SetBalancedRefinement_7(id0); }

  private native boolean GetBalancedRefinement_8();
  public boolean GetBalancedRefinement()
    { return GetBalancedRefinement_8(); }

  private native void SetNodeCentered_9(boolean id0);
  public void SetNodeCentered(boolean id0)
    { SetNodeCentered_9(id0); }

  private native boolean GetNodeCentered_10();
  public boolean GetNodeCentered()
    { return GetNodeCentered_10(); }

  private native void SetCellCentered_11(boolean id0);
  public void SetCellCentered(boolean id0)
    { SetCellCentered_11(id0); }

  private native boolean GetCellCentered_12();
  public boolean GetCellCentered()
    { return GetCellCentered_12(); }

  private native int GetNumberOfNeighbors_13(int id0);
  public int GetNumberOfNeighbors(int id0)
    { return GetNumberOfNeighbors_13(id0); }

  private native void GetGhostedExtent_14(int id0,int id1[]);
  public void GetGhostedExtent(int id0,int id1[])
    { GetGhostedExtent_14(id0,id1); }

  public vtkStructuredAMRGridConnectivity() { super(); }

  public vtkStructuredAMRGridConnectivity(long id) { super(id); }
  public native long   VTKInit();

}
